#include <iostream>
#include <sstream>
#include <vector>
#include <algorithm>
#include <cmath>
#include <unistd.h>
using namespace std;

// дано N точек, найти точки пересечения прямых проходящих через каждую пару точек,
// пересечений не совпадающих с самими концевыми точками (смежные прямые)

const double eps = 1E-3;

struct point { 
   double x, y; 
   bool operator==( const point& p ) {
      return ( fabs( p.x - x ) < eps ) && 
             ( fabs( p.y - y ) < eps ); 
   }
};
ostream& operator <<( ostream& out, const point& p ) {
   char s[ 20 ];
   sprintf( s, "<%+.2f,%+.2f>", p.x, p.y );   
   return out << s; 
}

struct line { point b, f; };
vector< line > lines;

bool parallel( line& l1, line& l2 ) {
   double x1 = l1.b.x, x2 = l1.f.x, x3 = l2.b.x, x4 = l2.f.x,
          y1 = l1.b.y, y2 = l1.f.y, y3 = l2.b.y, y4 = l2.f.y;
   return eps > fabs( ( x1 - x2 ) * ( y3 - y4 ) - 
                      ( y1 - y2 ) * ( x3 - x4 ) ); // denominator    
}

point cross( line& l1, line& l2 ) {
   double x1 = l1.b.x, x2 = l1.f.x, x3 = l2.b.x, x4 = l2.f.x,
          y1 = l1.b.y, y2 = l1.f.y, y3 = l2.b.y, y4 = l2.f.y,
          denominator = ( x1 - x2 ) * ( y3 - y4 ) -
                        ( y1 - y2 ) * ( x3 - x4 );
   point ret = {
      ( ( x1 * y2 - y1 * x2 ) * ( x3 - x4 ) - 
        ( x1 - x2 ) * ( x3 * y4 - y3 * x4 ) ) / denominator,
      ( ( x1 * y2 - y1 * x2 ) * ( y3 - y4 ) -
        ( y1 - y2 ) * ( x3 * y4 - y3 * x4 ) ) / denominator 
               };
   return ret;
}

int main( int argc, char **argv ) {
   vector<point> pts;
   int n = 0;
   point p; 
   while( cin ) {
      string s;   
      getline( cin, s );
      if( 0 == s.length() ) break;
      istringstream( s ) >> p.x >> p.y;  
      for( auto &x : pts ) {
         line l = { x, p };
         lines.push_back( l );
      }
      pts.push_back( p );
      n++;
   }
   if( !isatty( 0 ) ) {           // вывод при переадресации <
      for( auto &p : pts )
         cout << p << "  ";
      cout << endl;
   }         
   cout << n << "-угольник, " << lines.size() << " линий, " << endl;   
   int nc = 0, np = 0, nt = 0;
   n = 0;
   const int nline = 5;
   for( auto i = lines.begin(); i < lines.end(); i++ )
      for( auto j = i + 1; j < lines.end(); j++, n++ )
         if( parallel( *i, *j ) )
            np++;
         else {
            point c = cross( *i, *j );
            if( find( pts.begin(), pts.end(), c ) != pts.end() ) 
               nt++;
            else 
               cout << c << ( ++nc % nline ? "\t" : "\n" );
         }    
   cout << ( nc % nline ? "\n" : "" )
        << n << ": пересечений " << nc << " терминальных " 
        << nt  << " параллельных " << np << endl;   
}
